@@ -43,11 +43,12 @@ wvGetRowTap (wvParseStruct * ps, PAP * dpap, U32 para_intervals,
 	     BTE * btePapx, U32 * posPapx)
 {
     PAPX_FKP para_fkp;
+	
     U32 para_fcFirst, para_fcLim = 0xffffffffL;
     PAP apap;
     U32 i;
     S32 j = 0;
-
+    wvVersion ver = wvQuerySupported (&ps->fib, NULL);
     wvCopyPAP (&apap, dpap);
 
     wvInitPAPX_FKP (&para_fkp);
@@ -57,12 +58,11 @@ wvGetRowTap (wvParseStruct * ps, PAP * dpap, U32 para_intervals,
     do
       {
 	  wvReleasePAPX_FKP (&para_fkp);
-	  wvGetSimpleParaBounds (wvQuerySupported (&ps->fib, NULL), &para_fkp,
+	  wvGetSimpleParaBounds (ver, &para_fkp,
 				 &para_fcFirst, &para_fcLim, i, btePapx,
 				 posPapx, para_intervals, ps->mainfd);
 	  wvTrace (("2: para from %x to %x\n", para_fcFirst, para_fcLim));
-	  wvAssembleSimplePAP (wvQuerySupported (&ps->fib, NULL), &apap,
-			       para_fcLim, &para_fkp, &ps->stsh, ps->data);
+	  wvAssembleSimplePAP (ver, &apap, para_fcLim, &para_fkp, ps);
 	  i = para_fcLim;
       }
     while (apap.fTtp == 0);
@@ -81,11 +81,11 @@ wvGetFullTableInit (wvParseStruct * ps, U32 para_intervals, BTE * btePapx,
 		    U32 * posPapx)
 {
     PAPX_FKP para_fkp;
-    U32 para_fcFirst, para_fcLim = 0xffffffffL;
+	U32 para_fcFirst, para_fcLim = 0xffffffffL;
     PAP apap;
     U32 i, j = 0;
     TAP *test = NULL;
-
+    wvVersion ver = wvQuerySupported (&ps->fib, NULL);
     if (ps->intable)
 	return;
 
@@ -96,11 +96,10 @@ wvGetFullTableInit (wvParseStruct * ps, U32 para_intervals, BTE * btePapx,
     do
       {
 	  wvReleasePAPX_FKP (&para_fkp);
-	  wvGetSimpleParaBounds (wvQuerySupported (&ps->fib, NULL), &para_fkp,
+	  wvGetSimpleParaBounds (ver, &para_fkp,
 				 &para_fcFirst, &para_fcLim, i, btePapx,
 				 posPapx, para_intervals, ps->mainfd);
-	  wvAssembleSimplePAP (wvQuerySupported (&ps->fib, NULL), &apap,
-			       para_fcLim, &para_fkp, &ps->stsh, ps->data);
+	  wvAssembleSimplePAP (ver, &apap, para_fcLim, &para_fkp, ps);
 	  wvTrace (("para from %x to %x\n", para_fcFirst, para_fcLim));
 	  i = para_fcLim;
 
@@ -213,11 +212,11 @@ wvSetTableInfo (wvParseStruct * ps, TAP * ptap, int no)
     wvTrace (("end of out\n"));
 
     ps->vmerges = (S16 **) wvMalloc (sizeof (S16 *) * no);
-    wvTrace (("no of rows is %d", no));
+    wvTrace (("no of rows is %d\n", no));
     for (i = 0; i < no; i++)
       {
 	  ps->vmerges[i] = (S16 *) wvMalloc (sizeof (S16) * ptap[i].itcMac);
-	  wvTrace (("no of cells is %d", ptap[i].itcMac));
+	  wvTrace (("no of cells is %d\n", ptap[i].itcMac));
 	  for (j = 0; j < ptap[i].itcMac; j++)
 	      ps->vmerges[i][j] = 1;
       }
@@ -692,9 +691,9 @@ TheTest (wvParseStruct * ps, U32 piece, BTE * btePapx, U32 * posPapx,
     U32 i, j, k = 0;
     U32 para_fcFirst, para_fcLim;
     PAPX_FKP para_fkp;
-    PAP apap;
+	PAP apap;
     int cpiece = 0;
-
+    wvVersion ver = wvQuerySupported (&ps->fib, NULL);
     long pos = wvStream_tell (ps->mainfd);
     wvInitPAPX_FKP (&para_fkp);
 
@@ -735,11 +734,9 @@ TheTest (wvParseStruct * ps, U32 piece, BTE * btePapx, U32 * posPapx,
 			       ("cp and fc are %x(%d) %x\n", i, i,
 				wvConvertCPToFC (i, &ps->clx)));
 		      cpiece =
-			  wvGetComplexParaBounds (wvQuerySupported
-						  (&ps->fib, NULL), &para_fkp,
+			  wvGetComplexParaBounds (ver, &para_fkp,
 						  &para_fcFirst, &para_fcLim,
-						  wvConvertCPToFC (i,
-								   &ps->clx),
+						  wvConvertCPToFC (i, &ps->clx),
 						  &ps->clx, btePapx, posPapx,
 						  para_intervals, piececount,
 						  ps->mainfd);
@@ -750,12 +747,8 @@ TheTest (wvParseStruct * ps, U32 piece, BTE * btePapx, U32 * posPapx,
 		  }
 		if (j == para_fcFirst)
 		  {
-		      wvAssembleSimplePAP (wvQuerySupported (&ps->fib, NULL),
-					   &apap, para_fcLim, &para_fkp,
-					   &ps->stsh, ps->data);
-		      wvAssembleComplexPAP (wvQuerySupported (&ps->fib, NULL),
-					    &apap, cpiece, &ps->stsh,
-					    &ps->clx, ps->data);
+		      wvAssembleSimplePAP (ver, &apap, para_fcLim, &para_fkp, ps);
+		      wvAssembleComplexPAP (ver, &apap, cpiece, ps);
 		      wvTrace (
 			       ("table ttp are %d %d\n", apap.fInTable,
 				apap.fTtp));
@@ -771,12 +764,12 @@ wvGetComplexFullTableInit (wvParseStruct * ps, U32 para_intervals,
 			   BTE * btePapx, U32 * posPapx, U32 piece)
 {
     PAPX_FKP para_fkp;
-    U32 para_fcFirst, para_fcLim = 0xffffffffL;
+	U32 para_fcFirst, para_fcLim = 0xffffffffL;
     PAP apap;
     U32 i, j = 0, k = 0;
     S32 l;
     TAP *test = NULL;
-
+    wvVersion ver = wvQuerySupported (&ps->fib, NULL);
     if (ps->intable)
 	return;
 
@@ -800,7 +793,7 @@ wvGetComplexFullTableInit (wvParseStruct * ps, U32 para_intervals,
 		   ("2: cp and fc are %x(%d) %x\n", i, i,
 		    wvConvertCPToFC (i, &ps->clx)));
 	  piece =
-	      wvGetComplexParaBounds (wvQuerySupported (&ps->fib, NULL),
+	      wvGetComplexParaBounds (ver,
 				      &para_fkp, &para_fcFirst, &para_fcLim,
 				      i, &ps->clx, btePapx, posPapx,
 				      para_intervals, piece, ps->mainfd);
@@ -808,11 +801,11 @@ wvGetComplexFullTableInit (wvParseStruct * ps, U32 para_intervals,
 
 	  if (piece == 0xffffffffL)
 	      break;
-	  wvAssembleSimplePAP (wvQuerySupported (&ps->fib, NULL), &apap,
-			       para_fcLim, &para_fkp, &ps->stsh, ps->data);
+	  wvAssembleSimplePAP (ver, &apap,
+			       para_fcLim, &para_fkp, ps);
 	  wvTrace (("para from %x to %x\n", para_fcFirst, para_fcLim));
-	  wvAssembleComplexPAP (wvQuerySupported (&ps->fib, NULL), &apap,
-				piece, &ps->stsh, &ps->clx, ps->data);
+	  wvAssembleComplexPAP (ver, &apap,
+				piece, ps);
 
 	  wvTrace (("para from %x to %x\n", para_fcFirst, para_fcLim));
 	  i = para_fcLim;
@@ -850,11 +843,11 @@ wvGetComplexRowTap (wvParseStruct * ps, PAP * dpap, U32 para_intervals,
 		    BTE * btePapx, U32 * posPapx, U32 piece)
 {
     PAPX_FKP para_fkp;
-    U32 para_fcFirst, para_fcLim = 0xffffffffL;
+	U32 para_fcFirst, para_fcLim = 0xffffffffL;
     PAP apap;
     U32 i;
     S32 j = 0;
-
+    wvVersion ver = wvQuerySupported (&ps->fib, NULL);
     wvCopyPAP (&apap, dpap);
 
     wvInitPAPX_FKP (&para_fkp);
@@ -869,16 +862,13 @@ wvGetComplexRowTap (wvParseStruct * ps, PAP * dpap, U32 para_intervals,
 		   ("3: cp and fc are %x(%d) %x\n", i, i,
 		    wvConvertCPToFC (i, &ps->clx)));
 	  piece =
-	      wvGetComplexParaBounds (wvQuerySupported (&ps->fib, NULL),
-				      &para_fkp, &para_fcFirst, &para_fcLim,
+	      wvGetComplexParaBounds (ver, &para_fkp, &para_fcFirst, &para_fcLim,
 				      i, &ps->clx, btePapx, posPapx,
 				      para_intervals, piece, ps->mainfd);
 	  if (piece == 0xffffffffL)
 	      break;
-	  wvAssembleSimplePAP (wvQuerySupported (&ps->fib, NULL), &apap,
-			       para_fcLim, &para_fkp, &ps->stsh, ps->data);
-	  wvAssembleComplexPAP (wvQuerySupported (&ps->fib, NULL), &apap,
-				piece, &ps->stsh, &ps->clx, ps->data);
+	  wvAssembleSimplePAP (ver, &apap, para_fcLim, &para_fkp, ps);
+	  wvAssembleComplexPAP (ver, &apap, piece, ps);
 	  wvTrace (
 		   ("para from %x to %x, table is %d\n", para_fcFirst,
 		    para_fcLim, apap.fInTable));
